# print() is required for py3 not py2. so need to disable C0325
# pylint: disable=C0325
# pylint: disable=W0232
# pylint: disable=E0611
# pylint: disable=E1101
"""
Usage:
    netshow access [all] [--mac | -m ] [--oneline | -1  | --json | -j]
    netshow bondmems [all] [--mac | -m ] [--oneline | -1  | --json | -j]
    netshow bonds [all] [--mac | -m ] [--oneline | -1  | --json | -j]
    netshow bridges [all] [--mac | -m ] [--oneline | -1  | --json | -j]
    netshow counters [errors] [all] [--json | -j]
    netshow interface [all|<iface>] [--mac | -m ] [--oneline | -1 | --json | -j]
    netshow l2 [all] [--mac | -m ] [--oneline | -1  | --json | -j]
    netshow l3 [all] [--mac | -m ] [--oneline | -1  | --json | -j]
    netshow lldp [--json | -j]
    netshow mgmt [all] [--mac | -m ] [--oneline | -1  | --json | -j]
    netshow system [--json | -j ]
    netshow trunks [all] [--mac | -m ] [--oneline | -1  | --json | -j]

Help:
    * default is to show intefaces only in the UP state.
    access                    summary of physical ports with l2 or l3 config
    bondmems                  summary of bond members
    bonds                     summary of bonds
    bridges                   summary of ports with bridge members
    counters                  summary of physical port counters.
    interface                 summary info of all interfaces
    interface <iface>         list summary of a single interface
    l2                        summary of access, trunk and bridge interfaces
    l3                        summary of ports with an IP.
    lldp                      physical device neighbor information
    mgmt                      summary of mgmt ports
    system                    system information
    trunks                    summary of trunk interfaces

Options:
    all        show all ports include those are down or admin down
    -1         alias for --oneline
    --json     print output in json
    --mac      show inteface MAC in output
    --oneline  output each entry on one line

Legend:
    UP      Carrier up
    UN      Carrier Up - bond member not in bond
    DN      Carrier Down.
    ADMDN   Admin Down. Use "ip link set <iface> up " to initialize
    DRMNT   Carrier Up - Link Dormant
    P       Active Bond Member
    D       Inactive Bond Member
"""
import sys
from network_docopt import NetworkDocopt
from netshow.cumulus.show_counters import ShowCounters
from netshow.cumulus.show_system import ShowSystem
from netshow.cumulus.show_interfaces import ShowInterfaces
from netshow.cumulus.show_neighbors import ShowNeighbors


def interface_related(_nd):
    """
    return: True if option inputed requires ShowInterfaces() to be activated
    """
    for _entry in ['access', 'bridges', 'bonds', 'bondmems',
                   'mgmt', 'l2', 'l3', 'phy', 'trunks', 'interface']:
        if _nd.get(_entry):
            return True
    return False


def run():
    """ run cumulus netshow version """
    # Note if the last arg was '--completions'
    print_options = False
    ended_with_space = False
    len_argv = len(sys.argv)

    if len_argv >= 2 and sys.argv[-2] == '--completions':
        print_options = True
        init_completion_cword = int(sys.argv[-1])
        len_argv_pre_tab_complete = len_argv - 3

        if init_completion_cword > len_argv_pre_tab_complete:
            ended_with_space = True
        else:
            ended_with_space = False

        sys.argv = sys.argv[0:-2]

    _nd = NetworkDocopt(__doc__)

    if print_options:
        _nd.print_options(ended_with_space)
    else:
        _nd.run()

        if interface_related(_nd):
            _showint = ShowInterfaces(_nd)
            print(_showint.run())
        elif _nd.get('system'):
            _showsys = ShowSystem(_nd)
            print(_showsys.run())
        elif _nd.get('lldp'):
            _shownei = ShowNeighbors(_nd)
            print(_shownei.run())
        elif _nd.get('counters'):
            _showcounters = ShowCounters(_nd)
            print(_showcounters.run())
        else:
            print(__doc__)
