# pylint: disable=E0611
""" Module for printout out linux device neighbors
"""
from netshow.linux.netjson_encoder import NetEncoder
from netshow.linux import print_iface
import netshowlib.linux.cache as linux_cache
from collections import OrderedDict
import json
import os
from tabulate import tabulate


class ShowNeighbors(object):
    """
    Class responsible for printing out basic linux device neighbor info
    """
    def __init__(self, cl):
        self.use_json = cl.get('--json') or cl.get('-j')
        self.ifacelist = OrderedDict()
        self.cache = linux_cache
        self.print_iface = print_iface

    def run(self):
        """
        :return: basic neighbor information based on data obtained on netshow-lib
        """
        if os.getuid():
            print "\nERROR: You must be root to run this command\n"
            return ''

        feature_cache = self.cache.Cache()
        feature_cache.run()
        for _ifacename in sorted(feature_cache.lldp.keys()):
            self.ifacelist[_ifacename] = self.print_iface.iface(_ifacename, feature_cache)

        if self.use_json:
            return json.dumps(self.ifacelist, cls=NetEncoder, sort_keys=True, indent=4)

        return self.print_neighbor_info()

    def print_neighbor_info(self):
        """
        :return: cli output of netshow neighbor
        """
        _header = ['Local Port', 'Speed', 'Mode', '',
                   'Remote Port', 'Remote  Host', 'Summary']
        _table = []
        for _iface in self.ifacelist.values():
            _table.append([_iface.name, _iface.speed,
                           _iface.port_category,
                           '====',
                           _iface.iface.lldp[0].get('adj_port'),
                           _iface.iface.lldp[0].get('adj_hostname'),
                           ', '.join(_iface.summary)])
            del _iface.iface.lldp[0]
            if _iface.iface.lldp:
                for _entry in _iface.iface.lldp:
                    _table.append(['', '', '', '====',
                                   _entry.get('adj_port'),
                                   _entry.get('adj_hostname')])

        return '\n' + tabulate(_table, _header) + '\n'
